summaryrefslogtreecommitdiffstats
path: root/kcontrol/background/bgmonitor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kcontrol/background/bgmonitor.cpp')
-rw-r--r--kcontrol/background/bgmonitor.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kcontrol/background/bgmonitor.cpp b/kcontrol/background/bgmonitor.cpp
index 3c2278722..f78a7b616 100644
--- a/kcontrol/background/bgmonitor.cpp
+++ b/kcontrol/background/bgmonitor.cpp
@@ -91,7 +91,7 @@ void BGMonitorArrangement::updateArrangement()
{
// In this function, sizes, etc have a normal value, and their "expanded"
// value. The expanded value is used for setting the size of the monitor
// image that tqcontains the preview of the background. The monitor image
// will set the background preview back to the normal value.
TQRect overallGeometry;
@@ -157,21 +157,21 @@ void BGMonitorArrangement::setPixmap( const KPixmap & pm )
BGMonitorLabel::BGMonitorLabel(TQWidget *parent, const char *name)
: TQLabel(parent, name)
{
- tqsetAlignment(AlignCenter);
+ setAlignment(AlignCenter);
setScaledContents(true);
setPixmap( TQPixmap( locate("data", "kcontrol/pics/monitor.png") ) );
m_pBGMonitor = new BGMonitor(this);
- TQWhatsThis::add( this, i18n("This picture of a monitor tqcontains a preview of what the current settings will look like on your desktop.") );
+ TQWhatsThis::add( this, i18n("This picture of a monitor contains a preview of what the current settings will look like on your desktop.") );
}
void BGMonitorLabel::updateMonitorGeometry()
{
- double scaleX = double(width()) / double(tqsizeHint().width());
- double scaleY = double(height()) / double(tqsizeHint().height());
+ double scaleX = double(width()) / double(sizeHint().width());
+ double scaleY = double(height()) / double(sizeHint().height());
- kdDebug() << k_funcinfo << " Setting tqgeometry to " << TQRect( int(23*scaleX), int(14*scaleY), int(151*scaleX), int(115*scaleY) ) << endl;
+ kdDebug() << k_funcinfo << " Setting geometry to " << TQRect( int(23*scaleX), int(14*scaleY), int(151*scaleX), int(115*scaleY) ) << endl;
m_pBGMonitor->setGeometry( int(23*scaleX), int(14*scaleY), int(151*scaleX), int(115*scaleY) );
}
@@ -189,7 +189,7 @@ void BGMonitorLabel::resizeEvent( TQResizeEvent * e )
BGMonitor::BGMonitor(TQWidget *parent, const char *name)
: TQLabel(parent, name)
{
- tqsetAlignment(AlignCenter);
+ setAlignment(AlignCenter);
setScaledContents(true);
setAcceptDrops(true);
}
@@ -91,7 +91,7 @@ void BGMonitorArrangement::updateArrangement()
// In this function, sizes, etc have a normal value, and their "expanded"
// value. The expanded value is used for setting the size of the monitor
- // image that tqcontains the preview of the background. The monitor image
+ // image that contains the preview of the background. The monitor image
// will set the background preview back to the normal value.
TQRect overallGeometry;